# Klausen

[![Build Status](https://travis-ci.org/cmutel/klausen.svg?branch=master)](https://travis-ci.org/cmutel/klausen) [![Build status](https://ci.appveyor.com/api/projects/status/2j5behso9hlnmj4x?svg=true)](https://ci.appveyor.com/project/cmutel/klausen) [![Coverage Status](https://coveralls.io/repos/github/cmutel/klausen/badge.svg?branch=master)](https://coveralls.io/github/cmutel/klausen?branch=master)

Parameterized model framework in Python.

## Installation

Requires [stats_arrays](https://stats-arrays.readthedocs.io/en/latest/).
